/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018-2020 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2020 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.events.commands;

import org.apache.karaf.shell.api.action.Action;
import org.apache.karaf.shell.api.action.Argument;
import org.apache.karaf.shell.api.action.Command;
import org.apache.karaf.shell.api.action.Completion;
import org.apache.karaf.shell.api.action.Option;
import org.apache.karaf.shell.api.action.lifecycle.Reference;
import org.apache.karaf.shell.api.action.lifecycle.Service;
import org.opennms.netmgt.events.api.EventConstants;
import org.opennms.netmgt.events.api.EventForwarder;
import org.opennms.netmgt.model.events.EventBuilder;

import com.google.common.base.Strings;

@Command(scope = "opennms", name = "reload-daemon", description = "Reload a specific daemon")
@Service
public class ReloadDaemonCommand implements Action {

    @Reference
    public EventForwarder eventForwarder;
    
    @Option(name = "-f", aliases = "--config-file", description = "Optional config-file to target for reload", required = false, multiValued = false)
    private String configFile;

    @Argument(index = 0, name = "daemonName", description = "deamon to reload", required = true, multiValued = false)
    @Completion(DaemonNameCompleter.class)
    String daemonName;

    @Override
    public Object execute() throws Exception {

        EventBuilder eventBuilder = new EventBuilder(EventConstants.RELOAD_DAEMON_CONFIG_UEI, "reload-daemon-command");
        eventBuilder.addParam(EventConstants.PARM_DAEMON_NAME, daemonName);
        if (! Strings.isNullOrEmpty(configFile)) {
            eventBuilder.addParam(EventConstants.PARM_CONFIG_FILE_NAME, configFile);
        }
        eventForwarder.sendNow(eventBuilder.getEvent());
        return null;
    }
}
