/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.navigate;

public class MenuDropdownNavBarEntry extends LocationBasedNavBarEntry {
    private String m_contents = null;

    /**
     * <p>getDisplayString</p>
     *
     * @return The text containing the menu entry/entries.
     */
    public String getDisplayString() {
        if (getName() == null || m_contents == null) return "";
        final StringBuilder sb = new StringBuilder();
        sb.append("<div class=\"nav-dropdown\">");
        sb.append("<a href=\"");
        if (getUrl() == null) {
            sb.append("#");
        } else {
            sb.append(getUrl());
        }
        sb.append("\" class=\"nav-dropdown\">");
        sb.append(getName());
        sb.append(" ");
        sb.append("<span class=\"nav-item\">\u25BC</span>");
        sb.append("</a>");
        sb.append("<ul>");
        sb.append(m_contents);
        sb.append("</ul>");
        sb.append("</div>");

        return sb.toString();
    }

    /**
     * If there are any {@link NavBarEntry} objects in this
     * dropdown object, return DISPLAY_NO_LINK (since the
     * individual entries will handle their own)
     */
    public DisplayStatus evaluate(final MenuContext context) {
        boolean display = false;
        if (hasEntries()) {
            final StringBuilder sb = new StringBuilder();
            for (final NavBarEntry entry : getEntries()) {
                final DisplayStatus status = entry.evaluate(context);
                switch (status) {
                case DISPLAY_LINK:
                    sb.append("<li><a href=\"" + entry.getUrl() + "\">" + entry.getName() + "</a></li>");
                    display = true;
                    break;
                case DISPLAY_NO_LINK:
                    sb.append("<li>" + entry.getName() + "</li>");
                    display = true;
                    break;
                default:
                    break;
                }
            }
            m_contents = sb.toString();
        }
        return display? DisplayStatus.DISPLAY_NO_LINK : DisplayStatus.NO_DISPLAY;
    }
}
