/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2006-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.web.navigate;

import java.util.List;
import java.util.Objects;
import java.util.function.Function;

import javax.servlet.http.HttpServletRequest;

public interface NavBarEntry {

    class NavBarContext implements MenuContext {
        private final String location;
        private final Function<String, Boolean> userInRoleFunction;

        public NavBarContext(String location, Function<String, Boolean> userInRoleFunction) {
            this.userInRoleFunction = Objects.requireNonNull(userInRoleFunction);
            this.location = location;
        }

        @Override
        public String getLocation() {
            return location;
        }

        @Override
        public boolean isUserInRole(String role) {
            return userInRoleFunction.apply(role);
        }
    }

    String getName();
    String getDisplayString();
    String getUrl();

    /**
     * If this navbar entry has sub-entries, return them.  May return null if there are no sub-entries.
     */
    List<NavBarEntry> getEntries();
    boolean hasEntries();

    DisplayStatus evaluate(MenuContext context);

    /**
     * Return an object that represents whether or not the entry should be displayed and/or linked.
     *
     * @deprecated use {@link #evaluate(MenuContext)} instead.
     */
    @Deprecated
    default DisplayStatus evaluate(HttpServletRequest request) {
        final String location = request.getParameter("location");
        final Function<String, Boolean> userInRoleFunction = s -> request.isUserInRole(s);
        return evaluate(new NavBarContext(location, userInRoleFunction));
    }
}
